@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "real-auto-save" "26.1.0"
+(define-package "real-auto-save" "20260107.1112"
   "Automatically save your buffers/files at regular intervals."
   '((emacs "24.4"))
   :url "https://github.com/ChillarAnand/real-auto-save"
